# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/time/time_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/time/time_service.proto',
  package='yamcs.protobuf.time',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\020TimeServiceProtoP\001',
  serialized_pb=b'\n&yamcs/protobuf/time/time_service.proto\x12\x13yamcs.protobuf.time\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\"\xb1\x01\n\x10LeapSecondsTable\x12\x43\n\x06ranges\x18\x01 \x03(\x0b\x32\x33.yamcs.protobuf.time.LeapSecondsTable.ValidityRange\x1aX\n\rValidityRange\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0c\n\x04stop\x18\x02 \x01(\t\x12\x13\n\x0bleapSeconds\x18\x03 \x01(\x05\x12\x15\n\rtaiDifference\x18\x04 \x01(\x05\"q\n\x0eSetTimeRequest\x12\x10\n\x08instance\x18\x06 \x01(\t\x12)\n\x05time0\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x65lapsedTime\x18\x03 \x01(\x03\x12\r\n\x05speed\x18\x04 \x01(\x01\";\n\x14SubscribeTimeRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\";\n\x08TimeInfo\x12/\n\x0b\x63urrentTime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xd3\x02\n\x07TimeApi\x12h\n\x0eGetLeapSeconds\x12\x16.google.protobuf.Empty\x1a%.yamcs.protobuf.time.LeapSecondsTable\"\x17\x8a\x92\x03\x13\n\x11/api/leap-seconds\x12r\n\x07SetTime\x12#.yamcs.protobuf.time.SetTimeRequest\x1a\x16.google.protobuf.Empty\"*\x8a\x92\x03&\x1a!/api/instances/{instance}:setTime:\x01*\x12\x64\n\rSubscribeTime\x12).yamcs.protobuf.time.SubscribeTimeRequest\x1a\x1a.google.protobuf.Timestamp\"\n\xda\x92\x03\x06\n\x04time0\x01\x1a\x04\xd0\x80\x01\x01\x42(\n\x12org.yamcs.protobufB\x10TimeServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_LEAPSECONDSTABLE_VALIDITYRANGE = _descriptor.Descriptor(
  name='ValidityRange',
  full_name='yamcs.protobuf.time.LeapSecondsTable.ValidityRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.time.LeapSecondsTable.ValidityRange.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.time.LeapSecondsTable.ValidityRange.stop', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leapSeconds', full_name='yamcs.protobuf.time.LeapSecondsTable.ValidityRange.leapSeconds', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='taiDifference', full_name='yamcs.protobuf.time.LeapSecondsTable.ValidityRange.taiDifference', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=332,
)

_LEAPSECONDSTABLE = _descriptor.Descriptor(
  name='LeapSecondsTable',
  full_name='yamcs.protobuf.time.LeapSecondsTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ranges', full_name='yamcs.protobuf.time.LeapSecondsTable.ranges', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LEAPSECONDSTABLE_VALIDITYRANGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=332,
)


_SETTIMEREQUEST = _descriptor.Descriptor(
  name='SetTimeRequest',
  full_name='yamcs.protobuf.time.SetTimeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.time.SetTimeRequest.instance', index=0,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time0', full_name='yamcs.protobuf.time.SetTimeRequest.time0', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elapsedTime', full_name='yamcs.protobuf.time.SetTimeRequest.elapsedTime', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed', full_name='yamcs.protobuf.time.SetTimeRequest.speed', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=334,
  serialized_end=447,
)


_SUBSCRIBETIMEREQUEST = _descriptor.Descriptor(
  name='SubscribeTimeRequest',
  full_name='yamcs.protobuf.time.SubscribeTimeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.time.SubscribeTimeRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.time.SubscribeTimeRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=449,
  serialized_end=508,
)


_TIMEINFO = _descriptor.Descriptor(
  name='TimeInfo',
  full_name='yamcs.protobuf.time.TimeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currentTime', full_name='yamcs.protobuf.time.TimeInfo.currentTime', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=510,
  serialized_end=569,
)

_LEAPSECONDSTABLE_VALIDITYRANGE.containing_type = _LEAPSECONDSTABLE
_LEAPSECONDSTABLE.fields_by_name['ranges'].message_type = _LEAPSECONDSTABLE_VALIDITYRANGE
_SETTIMEREQUEST.fields_by_name['time0'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMEINFO.fields_by_name['currentTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['LeapSecondsTable'] = _LEAPSECONDSTABLE
DESCRIPTOR.message_types_by_name['SetTimeRequest'] = _SETTIMEREQUEST
DESCRIPTOR.message_types_by_name['SubscribeTimeRequest'] = _SUBSCRIBETIMEREQUEST
DESCRIPTOR.message_types_by_name['TimeInfo'] = _TIMEINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LeapSecondsTable = _reflection.GeneratedProtocolMessageType('LeapSecondsTable', (_message.Message,), {

  'ValidityRange' : _reflection.GeneratedProtocolMessageType('ValidityRange', (_message.Message,), {
    'DESCRIPTOR' : _LEAPSECONDSTABLE_VALIDITYRANGE,
    '__module__' : 'yamcs.protobuf.time.time_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.time.LeapSecondsTable.ValidityRange)
    })
  ,
  'DESCRIPTOR' : _LEAPSECONDSTABLE,
  '__module__' : 'yamcs.protobuf.time.time_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.time.LeapSecondsTable)
  })
_sym_db.RegisterMessage(LeapSecondsTable)
_sym_db.RegisterMessage(LeapSecondsTable.ValidityRange)

SetTimeRequest = _reflection.GeneratedProtocolMessageType('SetTimeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETTIMEREQUEST,
  '__module__' : 'yamcs.protobuf.time.time_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.time.SetTimeRequest)
  })
_sym_db.RegisterMessage(SetTimeRequest)

SubscribeTimeRequest = _reflection.GeneratedProtocolMessageType('SubscribeTimeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBETIMEREQUEST,
  '__module__' : 'yamcs.protobuf.time.time_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.time.SubscribeTimeRequest)
  })
_sym_db.RegisterMessage(SubscribeTimeRequest)

TimeInfo = _reflection.GeneratedProtocolMessageType('TimeInfo', (_message.Message,), {
  'DESCRIPTOR' : _TIMEINFO,
  '__module__' : 'yamcs.protobuf.time.time_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.time.TimeInfo)
  })
_sym_db.RegisterMessage(TimeInfo)


DESCRIPTOR._options = None

_TIMEAPI = _descriptor.ServiceDescriptor(
  name='TimeApi',
  full_name='yamcs.protobuf.time.TimeApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\320\200\001\001',
  serialized_start=572,
  serialized_end=911,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetLeapSeconds',
    full_name='yamcs.protobuf.time.TimeApi.GetLeapSeconds',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LEAPSECONDSTABLE,
    serialized_options=b'\212\222\003\023\n\021/api/leap-seconds',
  ),
  _descriptor.MethodDescriptor(
    name='SetTime',
    full_name='yamcs.protobuf.time.TimeApi.SetTime',
    index=1,
    containing_service=None,
    input_type=_SETTIMEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003&\032!/api/instances/{instance}:setTime:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeTime',
    full_name='yamcs.protobuf.time.TimeApi.SubscribeTime',
    index=2,
    containing_service=None,
    input_type=_SUBSCRIBETIMEREQUEST,
    output_type=google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP,
    serialized_options=b'\332\222\003\006\n\004time',
  ),
])
_sym_db.RegisterServiceDescriptor(_TIMEAPI)

DESCRIPTOR.services_by_name['TimeApi'] = _TIMEAPI

# @@protoc_insertion_point(module_scope)



import datetime
from typing import Iterable, Optional

from yamcs.client.core import pagination
from yamcs.client.core.context import Context
from yamcs.client.core.helpers import to_isostring
from yamcs.client.timeline.model import Band, Item, View
from yamcs.protobuf.timeline import timeline_pb2

__all__ = [
    "TimelineClient",
]


class TimelineClient:
    """
    Client for working with Yamcs timeline.
    """

    def __init__(self, ctx: Context, instance: str):
        super(TimelineClient, self).__init__()
        self.ctx = ctx
        self._instance = instance

    def list_views(self) -> Iterable[View]:
        """
        List the views.
        """
        # Server does not do pagination on listings of this resource.
        # Return an iterator anyway for similarity with other API methods
        response = self.ctx.get_proto(f"/timeline/{self._instance}/views")
        message = timeline_pb2.ListViewsResponse()
        message.ParseFromString(response.content)
        return iter([View(proto) for proto in getattr(message, "views")])

    def get_view(self, id: str) -> View:
        """
        Fetch a view by its identifier.

        :param id:
            View identifier
        """
        url = f"/timeline/{self._instance}/views/{id}"
        response = self.ctx.get_proto(url)
        message = timeline_pb2.TimelineView()
        message.ParseFromString(response.content)
        return View(message)

    def save_view(self, view: View):
        """
        Save or update a view.

        :param view:
            View object
        """
        if view.id:
            url = f"/timeline/{self._instance}/views/{view.id}"
            req = timeline_pb2.UpdateViewRequest()
        else:
            url = f"/timeline/{self._instance}/views"
            req = timeline_pb2.AddViewRequest()

        req.name = view._proto.name
        req.description = view._proto.description
        req.bands[:] = [band.id for band in view._proto.bands]

        if view.id:
            response = self.ctx.put_proto(url, data=req.SerializeToString())
        else:
            response = self.ctx.post_proto(url, data=req.SerializeToString())

        message = timeline_pb2.TimelineView()
        message.ParseFromString(response.content)
        view._proto = message

    def delete_view(self, view: str):
        """
        Delete a view.

        :param view:
            View identifier.
        """
        url = f"/timeline/{self._instance}/views/{view}"
        self.ctx.delete_proto(url)

    def list_bands(self) -> Iterable[Band]:
        """
        List the bands.
        """
        # Server does not do pagination on listings of this resource.
        # Return an iterator anyway for similarity with other API methods
        response = self.ctx.get_proto(f"/timeline/{self._instance}/bands")
        message = timeline_pb2.ListBandsResponse()
        message.ParseFromString(response.content)
        return iter([Band._as_subclass(proto) for proto in getattr(message, "bands")])

    def get_band(self, id: str) -> Band:
        """
        Fetch a band by its identifier.

        :param id:
            Band identifier
        """
        url = f"/timeline/{self._instance}/bands/{id}"
        response = self.ctx.get_proto(url)
        message = timeline_pb2.TimelineBand()
        message.ParseFromString(response.content)
        return Band._as_subclass(message)

    def save_band(self, band: Band):
        """
        Save or update a band.

        :param band:
            Band object
        """
        if band.id:
            url = f"/timeline/{self._instance}/bands/{band.id}"
            req = timeline_pb2.UpdateBandRequest()
        else:
            url = f"/timeline/{self._instance}/bands"
            req = timeline_pb2.AddBandRequest()
            req.source = "rdb"
            req.type = band._proto.type

        req.shared = True
        req.name = band._proto.name
        req.description = band._proto.description
        for k in band._proto.tags:
            req.tags.append(k)
        for k, v in band._as_properties().items():
            req.properties[k] = v

        if band.id:
            response = self.ctx.put_proto(url, data=req.SerializeToString())
        else:
            response = self.ctx.post_proto(url, data=req.SerializeToString())

        message = timeline_pb2.TimelineBand()
        message.ParseFromString(response.content)
        band._proto = message

    def delete_band(self, band: str):
        """
        Delete a band.

        :param band:
            Band identifier.
        """
        url = f"/timeline/{self._instance}/bands/{band}"
        self.ctx.delete_proto(url)

    def list_items(
        self,
        band: Optional[str] = None,
        start: Optional[datetime.datetime] = None,
        stop: Optional[datetime.datetime] = None,
        page_size: int = 500,
    ) -> Iterable[Item]:
        """
        List the items.

        :param band:
            Return only items matching the specified band
        :param start:
            Minimum stop time of the returned items (exclusive)
        :param stop:
            Maximum start time of the returned items (exclusive)
        :param page_size:
            Page size of underlying requests. Higher values imply less
            overhead, but risk hitting the maximum message size limit.
        """
        params = {}
        if band is not None:
            params["band"] = band
        if page_size is not None:
            params["limit"] = page_size
        if start is not None:
            params["start"] = to_isostring(start)
        if stop is not None:
            params["stop"] = to_isostring(stop)

        return pagination.Iterator(
            ctx=self.ctx,
            path=f"/timeline/{self._instance}/items",
            params=params,
            response_class=timeline_pb2.ListItemsResponse,
            items_key="items",
            item_mapper=Item,
        )

    def get_item(self, id: str) -> Item:
        """
        Fetch an item by its identifier.

        :param id:
            Item identifier
        """
        url = f"/timeline/{self._instance}/items/{id}"
        response = self.ctx.get_proto(url)
        message = timeline_pb2.TimelineItem()
        message.ParseFromString(response.content)
        return Item(message)

    def save_item(self, item: Item):
        """
        Save or update an item.

        :param item:
            Item object
        """
        if item.id:
            url = f"/timeline/{self._instance}/items/{item.id}"
            req = timeline_pb2.UpdateItemRequest()
        else:
            url = f"/timeline/{self._instance}/items"
            req = timeline_pb2.CreateItemRequest()
            req.type = item._proto.type

        if item._proto.HasField("name"):
            req.name = item._proto.name

        if item._proto.tags:
            req.tags.MergeFrom(item._proto.tags)
        elif item.id:
            req.clearTags = True

        if item._proto.properties:
            req.properties.MergeFrom(item._proto.properties)
        elif item.id:
            req.clearProperties = True

        req.start.MergeFrom(item._proto.start)
        if item._proto.HasField("duration"):
            req.duration.MergeFrom(item._proto.duration)
        if item._proto.HasField("activityDefinition"):
            req.activityDefinition.MergeFrom(item._proto.activityDefinition)

        if item.id:
            response = self.ctx.put_proto(url, data=req.SerializeToString())
        else:
            response = self.ctx.post_proto(url, data=req.SerializeToString())

        message = timeline_pb2.TimelineItem()
        message.ParseFromString(response.content)
        item._proto = message

    def delete_item(self, item: str):
        """
        Delete an item.

        :param item:
            Item identifier.
        """
        url = f"/timeline/{self._instance}/items/{item}"
        self.ctx.delete_proto(url)



import warnings

warnings.warn(
    "The module 'yamcs.filetransfer' is deprecated. "
    "Import classes from 'yamcs.client' instead.",
    DeprecationWarning,
    stacklevel=2,
)

from yamcs.client.filetransfer.client import FileTransferClient  # noqa



import warnings

warnings.warn(
    "The module 'yamcs.tmtc.model' is deprecated. "
    "Import classes from 'yamcs.client' instead.",
    DeprecationWarning,
    stacklevel=2,
)

from yamcs.client.tmtc.model import (  # noqa
    Acknowledgment,
    Alarm,
    AlarmRangeSet,
    AlarmUpdate,
    Calibrator,
    CommandHistory,
    ContainerData,
    EventAlarm,
    IssuedCommand,
    MonitoredCommand,
    Packet,
    ParameterAlarm,
    ParameterData,
    ParameterValue,
    ValueUpdate,
    VerificationConfig,
)

RangeSet = AlarmRangeSet
"""
Temporary backwards compatibility.
Prefer to use the class 'AlarmRangeSet'.
"""



import datetime
from typing import IO, TYPE_CHECKING, List, Mapping, Optional, Union

from yamcs.client.core.helpers import parse_server_time

if TYPE_CHECKING:
    from yamcs.client.storage.client import StorageClient


__all__ = [
    "Bucket",
    "ObjectInfo",
    "ObjectListing",
]


class Bucket:
    def __init__(self, proto, storage_client: "StorageClient"):
        self._proto = proto
        self._storage_client = storage_client

    @property
    def name(self) -> str:
        """Name of this bucket."""
        return self._proto.name

    @property
    def created(self) -> datetime.datetime:
        """
        When this bucket was created.
        """
        return parse_server_time(self._proto.created)

    @property
    def object_count(self) -> int:
        """Number of objects in this bucket."""
        return self._proto.numObjects

    @property
    def max_object_count(self) -> Optional[int]:
        """Maximum allowed number of objects."""
        if self._proto.HasField("maxObjects"):
            return self._proto.maxObjects
        return None

    @property
    def size(self) -> int:
        """Total size in bytes of this bucket (excluding metadata)."""
        return self._proto.size

    @property
    def max_size(self) -> Optional[int]:
        """Maximum allowed total size of all objects."""
        if self._proto.HasField("maxSize"):
            return self._proto.maxSize
        return None

    @property
    def directory(self) -> Optional[str]:
        """
        Bucket root directory. This field is only set when
        the bucket is mapped to the file system. Therefore
        it is not set for buckets that store objects in
        RocksDB.
        """
        if self._proto.HasField("directory"):
            return self._proto.directory
        return None

    def list_objects(
        self, prefix: Optional[str] = None, delimiter: Optional[str] = None
    ):
        """
        List the objects for this bucket.

        :param prefix:
            If specified, only objects that start with this prefix are listed.
        :param delimiter:
            If specified, return only objects whose name
            do not contain the delimiter after the prefix.
            For the other objects, the response contains
            (in the prefix response parameter) the name
            truncated after the delimiter. Duplicates are
            omitted.
        """
        return self._storage_client.list_objects(
            bucket_name=self.name,
            prefix=prefix,
            delimiter=delimiter,
        )

    def download_object(self, object_name: str) -> bytes:
        """
        Download an object.

        :param object_name:
            The object to fetch.
        """
        return self._storage_client.download_object(self.name, object_name)

    def upload_object(
        self,
        object_name: str,
        file_obj: Union[str, IO],
        content_type: Optional[str] = None,
        metadata: Optional[Mapping[str, str]] = None,
    ):
        """
        Upload an object to this bucket.

        :param object_name:
            The target name of the object.
        :param file_obj:
            The file (or file-like object) to upload.
        :param content_type:
            The content type associated to this object.
            This is mainly useful when accessing an object
            directly via a web browser. If unspecified, a
            content type *may* be automatically derived
            from the specified ``file_obj``.
        :param metadata:
            Optional metadata associated to this object.
        """
        return self._storage_client.upload_object(
            bucket_name=self.name,
            object_name=object_name,
            file_obj=file_obj,
            content_type=content_type,
            metadata=metadata,
        )

    def delete_object(self, object_name: str):
        """
        Remove an object from this bucket.

        :param object_name:
            The object to remove.
        """
        self._storage_client.remove_object(self.name, object_name)

    def delete(self):
        """
        Remove this bucket in its entirety.
        """
        self._storage_client.remove_bucket(self.name)

    def __str__(self):
        return self.name


class ObjectInfo:
    def __init__(self, proto, bucket, storage_client):
        self._proto = proto
        self._bucket = bucket
        self._storage_client = storage_client

    @property
    def name(self) -> str:
        """
        The name of this object.
        """
        return self._proto.name

    @property
    def size(self) -> int:
        """
        Size in bytes of this object (excluding metadata).
        """
        return self._proto.size

    @property
    def created(self) -> datetime.datetime:
        """
        Return when this object was created (or re-created).
        """
        return parse_server_time(self._proto.created)

    def delete(self):
        """
        Remove this object.
        """
        self._storage_client.remove_object(self._bucket, self.name)

    def download(self):
        """
        Download this object.
        """
        return self._storage_client.download_object(self._bucket, self.name)

    def upload(
        self,
        file_obj: Union[str, IO],
        metadata: Optional[Mapping[str, str]] = None,
    ):
        """
        Replace the content of this object.

        :param file_obj:
            The file (or file-like object) to upload.
        :param metadata:
            Optional metadata associated to this object.
        """
        return self._storage_client.upload_object(
            bucket_name=self._bucket,
            object_name=self.name,
            file_obj=file_obj,
            metadata=metadata,
        )

    def __str__(self):
        return f"{self.name} ({self.size} bytes, created {self.created})"


class ObjectListing:
    def __init__(self, proto, bucket, storage_client):
        self._proto = proto
        self._bucket = bucket
        self._storage_client = storage_client

    @property
    def prefixes(self) -> List[str]:
        """
        The prefixes in this listing.
        """
        return [p for p in self._proto.prefixes]

    @property
    def objects(self) -> List[ObjectInfo]:
        """
        The objects in this listing.
        """
        return [
            ObjectInfo(o, self._bucket, self._storage_client)
            for o in self._proto.objects
        ]



import warnings

warnings.warn(
    "The module 'yamcs.archive.model' is deprecated. "
    "Import classes from 'yamcs.client' instead.",
    DeprecationWarning,
    stacklevel=2,
)

from yamcs.client.archive.model import (  # noqa
    ColumnData,
    IndexGroup,
    IndexRecord,
    ParameterRange,
    ParameterRangeEntry,
    ResultSet,
    Sample,
    Stream,
    StreamData,
    Table,
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/audit/audit.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/audit/audit.proto',
  package='yamcs.protobuf.audit',
  syntax='proto2',
  serialized_options=b'\n\030org.yamcs.protobuf.auditB\021AuditServiceProtoP\001',
  serialized_pb=b'\n yamcs/protobuf/audit/audit.proto\x12\x14yamcs.protobuf.audit\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\"\xb9\x01\n\x17ListAuditRecordsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0c\n\x04next\x18\x03 \x01(\t\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\t\n\x01q\x18\x06 \x01(\t\x12\x0f\n\x07service\x18\x07 \x01(\t\"i\n\x18ListAuditRecordsResponse\x12\x32\n\x07records\x18\x01 \x03(\x0b\x32!.yamcs.protobuf.audit.AuditRecord\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"\xa1\x01\n\x0b\x41uditRecord\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x0e\n\x06method\x18\x03 \x01(\t\x12\x0c\n\x04user\x18\x04 \x01(\t\x12\x0f\n\x07summary\x18\x05 \x01(\t\x12(\n\x07request\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct2\xa9\x01\n\x08\x41uditApi\x12\x96\x01\n\x10ListAuditRecords\x12-.yamcs.protobuf.audit.ListAuditRecordsRequest\x1a..yamcs.protobuf.audit.ListAuditRecordsResponse\"#\x8a\x92\x03\x1f\n\x1d/api/audit/records/{instance}\x1a\x04\xd0\x80\x01\x01\x42/\n\x18org.yamcs.protobuf.auditB\x11\x41uditServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_LISTAUDITRECORDSREQUEST = _descriptor.Descriptor(
  name='ListAuditRecordsRequest',
  full_name='yamcs.protobuf.audit.ListAuditRecordsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.audit.ListAuditRecordsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.audit.ListAuditRecordsRequest.limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.audit.ListAuditRecordsRequest.next', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.audit.ListAuditRecordsRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.audit.ListAuditRecordsRequest.stop', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q', full_name='yamcs.protobuf.audit.ListAuditRecordsRequest.q', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service', full_name='yamcs.protobuf.audit.ListAuditRecordsRequest.service', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=336,
)


_LISTAUDITRECORDSRESPONSE = _descriptor.Descriptor(
  name='ListAuditRecordsResponse',
  full_name='yamcs.protobuf.audit.ListAuditRecordsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='records', full_name='yamcs.protobuf.audit.ListAuditRecordsResponse.records', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.audit.ListAuditRecordsResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=443,
)


_AUDITRECORD = _descriptor.Descriptor(
  name='AuditRecord',
  full_name='yamcs.protobuf.audit.AuditRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='yamcs.protobuf.audit.AuditRecord.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service', full_name='yamcs.protobuf.audit.AuditRecord.service', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='yamcs.protobuf.audit.AuditRecord.method', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='yamcs.protobuf.audit.AuditRecord.user', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary', full_name='yamcs.protobuf.audit.AuditRecord.summary', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request', full_name='yamcs.protobuf.audit.AuditRecord.request', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=607,
)

_LISTAUDITRECORDSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTAUDITRECORDSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTAUDITRECORDSRESPONSE.fields_by_name['records'].message_type = _AUDITRECORD
_AUDITRECORD.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_AUDITRECORD.fields_by_name['request'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['ListAuditRecordsRequest'] = _LISTAUDITRECORDSREQUEST
DESCRIPTOR.message_types_by_name['ListAuditRecordsResponse'] = _LISTAUDITRECORDSRESPONSE
DESCRIPTOR.message_types_by_name['AuditRecord'] = _AUDITRECORD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListAuditRecordsRequest = _reflection.GeneratedProtocolMessageType('ListAuditRecordsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTAUDITRECORDSREQUEST,
  '__module__' : 'yamcs.protobuf.audit.audit_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.audit.ListAuditRecordsRequest)
  })
_sym_db.RegisterMessage(ListAuditRecordsRequest)

ListAuditRecordsResponse = _reflection.GeneratedProtocolMessageType('ListAuditRecordsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAUDITRECORDSRESPONSE,
  '__module__' : 'yamcs.protobuf.audit.audit_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.audit.ListAuditRecordsResponse)
  })
_sym_db.RegisterMessage(ListAuditRecordsResponse)

AuditRecord = _reflection.GeneratedProtocolMessageType('AuditRecord', (_message.Message,), {
  'DESCRIPTOR' : _AUDITRECORD,
  '__module__' : 'yamcs.protobuf.audit.audit_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.audit.AuditRecord)
  })
_sym_db.RegisterMessage(AuditRecord)


DESCRIPTOR._options = None

_AUDITAPI = _descriptor.ServiceDescriptor(
  name='AuditApi',
  full_name='yamcs.protobuf.audit.AuditApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\320\200\001\001',
  serialized_start=610,
  serialized_end=779,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListAuditRecords',
    full_name='yamcs.protobuf.audit.AuditApi.ListAuditRecords',
    index=0,
    containing_service=None,
    input_type=_LISTAUDITRECORDSREQUEST,
    output_type=_LISTAUDITRECORDSRESPONSE,
    serialized_options=b'\212\222\003\037\n\035/api/audit/records/{instance}',
  ),
])
_sym_db.RegisterServiceDescriptor(_AUDITAPI)

DESCRIPTOR.services_by_name['AuditApi'] = _AUDITAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/tco/tco.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/tco/tco.proto',
  package='yamcs.protobuf.tco',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\010TcoProtoP\001',
  serialized_pb=b'\n\x1cyamcs/protobuf/tco/tco.proto\x12\x12yamcs.protobuf.tco\x1a\x1byamcs/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"<\n\x13GetTcoConfigRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\"k\n\x13SetTcoConfigRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\x12-\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x1d.yamcs.protobuf.tco.TcoConfig\"8\n\x0fTcoResetRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\"Y\n\tTcoConfig\x12\x10\n\x08\x61\x63\x63uracy\x18\x01 \x01(\x01\x12\x10\n\x08validity\x18\x02 \x01(\x01\x12\x14\n\x0conboardDelay\x18\x03 \x01(\x01\x12\x12\n\ndefaultTof\x18\x04 \x01(\x01\"<\n\x13GetTcoStatusRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\"z\n\x16SetCoefficientsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\x12\x39\n\x0c\x63oefficients\x18\x03 \x01(\x0b\x32#.yamcs.protobuf.tco.TcoCoefficients\"|\n\x1f\x41\x64\x64TimeOfFlightIntervalsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\x12\x32\n\tintervals\x18\x03 \x03(\x0b\x32\x1f.yamcs.protobuf.tco.TofInterval\"\xa0\x01\n\"DeleteTimeOfFlightIntervalsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\x12)\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"i\n\x0fTcoCoefficients\x12\'\n\x03utc\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03obt\x18\x02 \x01(\x04\x12\x10\n\x08gradient\x18\x03 \x01(\x01\x12\x0e\n\x06offset\x18\x04 \x01(\x01\"\xbf\x01\n\tTcoStatus\x12\x39\n\x0c\x63oefficients\x18\x01 \x01(\x0b\x32#.yamcs.protobuf.tco.TcoCoefficients\x12\x34\n\x10\x63oefficientsTime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tdeviation\x18\x03 \x01(\x01\x12.\n\x07samples\x18\x04 \x03(\x0b\x32\x1d.yamcs.protobuf.tco.TcoSample\"A\n\tTcoSample\x12\'\n\x03utc\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03obt\x18\x02 \x01(\x04\"y\n\x0bTofInterval\x12,\n\x08\x65rtStart\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07\x65rtStop\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07polCoef\x18\x03 \x03(\x01\x32\x95\x08\n\x12TimeCorrelationApi\x12\x83\x01\n\tGetConfig\x12\'.yamcs.protobuf.tco.GetTcoConfigRequest\x1a\x1d.yamcs.protobuf.tco.TcoConfig\".\x8a\x92\x03*\n(/api/tco/{instance}/{serviceName}/config\x12\x84\x01\n\tSetConfig\x12\'.yamcs.protobuf.tco.SetTcoConfigRequest\x1a\x16.google.protobuf.Empty\"6\x8a\x92\x03\x32\x1a(/api/tco/{instance}/{serviceName}/config:\x06\x63onfig\x12\x83\x01\n\tGetStatus\x12\'.yamcs.protobuf.tco.GetTcoStatusRequest\x1a\x1d.yamcs.protobuf.tco.TcoStatus\".\x8a\x92\x03*\n(/api/tco/{instance}/{serviceName}/status\x12\x99\x01\n\x0fSetCoefficients\x12*.yamcs.protobuf.tco.SetCoefficientsRequest\x1a\x16.google.protobuf.Empty\"B\x8a\x92\x03>\x1a./api/tco/{instance}/{serviceName}/coefficients:\x0c\x63oefficients\x12s\n\x05Reset\x12#.yamcs.protobuf.tco.TcoResetRequest\x1a\x16.google.protobuf.Empty\"-\x8a\x92\x03)\x1a\'/api/tco/{instance}/{serviceName}:reset\x12\xa4\x01\n\x18\x41\x64\x64TimeOfFlightIntervals\x12\x33.yamcs.protobuf.tco.AddTimeOfFlightIntervalsRequest\x1a\x16.google.protobuf.Empty\";\x8a\x92\x03\x37\x1a\x32/api/tco/{instance}/{serviceName}/tof:addIntervals:\x01*\x12\xad\x01\n\x1b\x44\x65leteTimeOfFlightIntervals\x12\x36.yamcs.protobuf.tco.DeleteTimeOfFlightIntervalsRequest\x1a\x16.google.protobuf.Empty\">\x8a\x92\x03:\x1a\x35/api/tco/{instance}/{serviceName}/tof:deleteIntervals:\x01*\x1a\x04\xd0\x80\x01\x01\x42 \n\x12org.yamcs.protobufB\x08TcoProtoP\x01'
  ,
  dependencies=[yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_GETTCOCONFIGREQUEST = _descriptor.Descriptor(
  name='GetTcoConfigRequest',
  full_name='yamcs.protobuf.tco.GetTcoConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.tco.GetTcoConfigRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.tco.GetTcoConfigRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=203,
)


_SETTCOCONFIGREQUEST = _descriptor.Descriptor(
  name='SetTcoConfigRequest',
  full_name='yamcs.protobuf.tco.SetTcoConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.tco.SetTcoConfigRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.tco.SetTcoConfigRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='yamcs.protobuf.tco.SetTcoConfigRequest.config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=312,
)


_TCORESETREQUEST = _descriptor.Descriptor(
  name='TcoResetRequest',
  full_name='yamcs.protobuf.tco.TcoResetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.tco.TcoResetRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.tco.TcoResetRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=370,
)


_TCOCONFIG = _descriptor.Descriptor(
  name='TcoConfig',
  full_name='yamcs.protobuf.tco.TcoConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='yamcs.protobuf.tco.TcoConfig.accuracy', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validity', full_name='yamcs.protobuf.tco.TcoConfig.validity', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onboardDelay', full_name='yamcs.protobuf.tco.TcoConfig.onboardDelay', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultTof', full_name='yamcs.protobuf.tco.TcoConfig.defaultTof', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=372,
  serialized_end=461,
)


_GETTCOSTATUSREQUEST = _descriptor.Descriptor(
  name='GetTcoStatusRequest',
  full_name='yamcs.protobuf.tco.GetTcoStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.tco.GetTcoStatusRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.tco.GetTcoStatusRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=523,
)


_SETCOEFFICIENTSREQUEST = _descriptor.Descriptor(
  name='SetCoefficientsRequest',
  full_name='yamcs.protobuf.tco.SetCoefficientsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.tco.SetCoefficientsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.tco.SetCoefficientsRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coefficients', full_name='yamcs.protobuf.tco.SetCoefficientsRequest.coefficients', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=525,
  serialized_end=647,
)


_ADDTIMEOFFLIGHTINTERVALSREQUEST = _descriptor.Descriptor(
  name='AddTimeOfFlightIntervalsRequest',
  full_name='yamcs.protobuf.tco.AddTimeOfFlightIntervalsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.tco.AddTimeOfFlightIntervalsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.tco.AddTimeOfFlightIntervalsRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intervals', full_name='yamcs.protobuf.tco.AddTimeOfFlightIntervalsRequest.intervals', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=649,
  serialized_end=773,
)


_DELETETIMEOFFLIGHTINTERVALSREQUEST = _descriptor.Descriptor(
  name='DeleteTimeOfFlightIntervalsRequest',
  full_name='yamcs.protobuf.tco.DeleteTimeOfFlightIntervalsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.tco.DeleteTimeOfFlightIntervalsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.tco.DeleteTimeOfFlightIntervalsRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.tco.DeleteTimeOfFlightIntervalsRequest.start', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.tco.DeleteTimeOfFlightIntervalsRequest.stop', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=776,
  serialized_end=936,
)


_TCOCOEFFICIENTS = _descriptor.Descriptor(
  name='TcoCoefficients',
  full_name='yamcs.protobuf.tco.TcoCoefficients',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='utc', full_name='yamcs.protobuf.tco.TcoCoefficients.utc', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='obt', full_name='yamcs.protobuf.tco.TcoCoefficients.obt', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gradient', full_name='yamcs.protobuf.tco.TcoCoefficients.gradient', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='yamcs.protobuf.tco.TcoCoefficients.offset', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=938,
  serialized_end=1043,
)


_TCOSTATUS = _descriptor.Descriptor(
  name='TcoStatus',
  full_name='yamcs.protobuf.tco.TcoStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coefficients', full_name='yamcs.protobuf.tco.TcoStatus.coefficients', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coefficientsTime', full_name='yamcs.protobuf.tco.TcoStatus.coefficientsTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deviation', full_name='yamcs.protobuf.tco.TcoStatus.deviation', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='samples', full_name='yamcs.protobuf.tco.TcoStatus.samples', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1046,
  serialized_end=1237,
)


_TCOSAMPLE = _descriptor.Descriptor(
  name='TcoSample',
  full_name='yamcs.protobuf.tco.TcoSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='utc', full_name='yamcs.protobuf.tco.TcoSample.utc', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='obt', full_name='yamcs.protobuf.tco.TcoSample.obt', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1239,
  serialized_end=1304,
)


_TOFINTERVAL = _descriptor.Descriptor(
  name='TofInterval',
  full_name='yamcs.protobuf.tco.TofInterval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ertStart', full_name='yamcs.protobuf.tco.TofInterval.ertStart', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ertStop', full_name='yamcs.protobuf.tco.TofInterval.ertStop', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='polCoef', full_name='yamcs.protobuf.tco.TofInterval.polCoef', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1306,
  serialized_end=1427,
)

_SETTCOCONFIGREQUEST.fields_by_name['config'].message_type = _TCOCONFIG
_SETCOEFFICIENTSREQUEST.fields_by_name['coefficients'].message_type = _TCOCOEFFICIENTS
_ADDTIMEOFFLIGHTINTERVALSREQUEST.fields_by_name['intervals'].message_type = _TOFINTERVAL
_DELETETIMEOFFLIGHTINTERVALSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DELETETIMEOFFLIGHTINTERVALSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TCOCOEFFICIENTS.fields_by_name['utc'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TCOSTATUS.fields_by_name['coefficients'].message_type = _TCOCOEFFICIENTS
_TCOSTATUS.fields_by_name['coefficientsTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TCOSTATUS.fields_by_name['samples'].message_type = _TCOSAMPLE
_TCOSAMPLE.fields_by_name['utc'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TOFINTERVAL.fields_by_name['ertStart'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TOFINTERVAL.fields_by_name['ertStop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['GetTcoConfigRequest'] = _GETTCOCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetTcoConfigRequest'] = _SETTCOCONFIGREQUEST
DESCRIPTOR.message_types_by_name['TcoResetRequest'] = _TCORESETREQUEST
DESCRIPTOR.message_types_by_name['TcoConfig'] = _TCOCONFIG
DESCRIPTOR.message_types_by_name['GetTcoStatusRequest'] = _GETTCOSTATUSREQUEST
DESCRIPTOR.message_types_by_name['SetCoefficientsRequest'] = _SETCOEFFICIENTSREQUEST
DESCRIPTOR.message_types_by_name['AddTimeOfFlightIntervalsRequest'] = _ADDTIMEOFFLIGHTINTERVALSREQUEST
DESCRIPTOR.message_types_by_name['DeleteTimeOfFlightIntervalsRequest'] = _DELETETIMEOFFLIGHTINTERVALSREQUEST
DESCRIPTOR.message_types_by_name['TcoCoefficients'] = _TCOCOEFFICIENTS
DESCRIPTOR.message_types_by_name['TcoStatus'] = _TCOSTATUS
DESCRIPTOR.message_types_by_name['TcoSample'] = _TCOSAMPLE
DESCRIPTOR.message_types_by_name['TofInterval'] = _TOFINTERVAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetTcoConfigRequest = _reflection.GeneratedProtocolMessageType('GetTcoConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTCOCONFIGREQUEST,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.GetTcoConfigRequest)
  })
_sym_db.RegisterMessage(GetTcoConfigRequest)

SetTcoConfigRequest = _reflection.GeneratedProtocolMessageType('SetTcoConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETTCOCONFIGREQUEST,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.SetTcoConfigRequest)
  })
_sym_db.RegisterMessage(SetTcoConfigRequest)

TcoResetRequest = _reflection.GeneratedProtocolMessageType('TcoResetRequest', (_message.Message,), {
  'DESCRIPTOR' : _TCORESETREQUEST,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.TcoResetRequest)
  })
_sym_db.RegisterMessage(TcoResetRequest)

TcoConfig = _reflection.GeneratedProtocolMessageType('TcoConfig', (_message.Message,), {
  'DESCRIPTOR' : _TCOCONFIG,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.TcoConfig)
  })
_sym_db.RegisterMessage(TcoConfig)

GetTcoStatusRequest = _reflection.GeneratedProtocolMessageType('GetTcoStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTCOSTATUSREQUEST,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.GetTcoStatusRequest)
  })
_sym_db.RegisterMessage(GetTcoStatusRequest)

SetCoefficientsRequest = _reflection.GeneratedProtocolMessageType('SetCoefficientsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCOEFFICIENTSREQUEST,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.SetCoefficientsRequest)
  })
_sym_db.RegisterMessage(SetCoefficientsRequest)

AddTimeOfFlightIntervalsRequest = _reflection.GeneratedProtocolMessageType('AddTimeOfFlightIntervalsRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDTIMEOFFLIGHTINTERVALSREQUEST,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.AddTimeOfFlightIntervalsRequest)
  })
_sym_db.RegisterMessage(AddTimeOfFlightIntervalsRequest)

DeleteTimeOfFlightIntervalsRequest = _reflection.GeneratedProtocolMessageType('DeleteTimeOfFlightIntervalsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETIMEOFFLIGHTINTERVALSREQUEST,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.DeleteTimeOfFlightIntervalsRequest)
  })
_sym_db.RegisterMessage(DeleteTimeOfFlightIntervalsRequest)

TcoCoefficients = _reflection.GeneratedProtocolMessageType('TcoCoefficients', (_message.Message,), {
  'DESCRIPTOR' : _TCOCOEFFICIENTS,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.TcoCoefficients)
  })
_sym_db.RegisterMessage(TcoCoefficients)

TcoStatus = _reflection.GeneratedProtocolMessageType('TcoStatus', (_message.Message,), {
  'DESCRIPTOR' : _TCOSTATUS,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.TcoStatus)
  })
_sym_db.RegisterMessage(TcoStatus)

TcoSample = _reflection.GeneratedProtocolMessageType('TcoSample', (_message.Message,), {
  'DESCRIPTOR' : _TCOSAMPLE,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.TcoSample)
  })
_sym_db.RegisterMessage(TcoSample)

TofInterval = _reflection.GeneratedProtocolMessageType('TofInterval', (_message.Message,), {
  'DESCRIPTOR' : _TOFINTERVAL,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.TofInterval)
  })
_sym_db.RegisterMessage(TofInterval)


DESCRIPTOR._options = None

_TIMECORRELATIONAPI = _descriptor.ServiceDescriptor(
  name='TimeCorrelationApi',
  full_name='yamcs.protobuf.tco.TimeCorrelationApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\320\200\001\001',
  serialized_start=1430,
  serialized_end=2475,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='yamcs.protobuf.tco.TimeCorrelationApi.GetConfig',
    index=0,
    containing_service=None,
    input_type=_GETTCOCONFIGREQUEST,
    output_type=_TCOCONFIG,
    serialized_options=b'\212\222\003*\n(/api/tco/{instance}/{serviceName}/config',
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='yamcs.protobuf.tco.TimeCorrelationApi.SetConfig',
    index=1,
    containing_service=None,
    input_type=_SETTCOCONFIGREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\0032\032(/api/tco/{instance}/{serviceName}/config:\006config',
  ),
  _descriptor.MethodDescriptor(
    name='GetStatus',
    full_name='yamcs.protobuf.tco.TimeCorrelationApi.GetStatus',
    index=2,
    containing_service=None,
    input_type=_GETTCOSTATUSREQUEST,
    output_type=_TCOSTATUS,
    serialized_options=b'\212\222\003*\n(/api/tco/{instance}/{serviceName}/status',
  ),
  _descriptor.MethodDescriptor(
    name='SetCoefficients',
    full_name='yamcs.protobuf.tco.TimeCorrelationApi.SetCoefficients',
    index=3,
    containing_service=None,
    input_type=_SETCOEFFICIENTSREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003>\032./api/tco/{instance}/{serviceName}/coefficients:\014coefficients',
  ),
  _descriptor.MethodDescriptor(
    name='Reset',
    full_name='yamcs.protobuf.tco.TimeCorrelationApi.Reset',
    index=4,
    containing_service=None,
    input_type=_TCORESETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003)\032\'/api/tco/{instance}/{serviceName}:reset',
  ),
  _descriptor.MethodDescriptor(
    name='AddTimeOfFlightIntervals',
    full_name='yamcs.protobuf.tco.TimeCorrelationApi.AddTimeOfFlightIntervals',
    index=5,
    containing_service=None,
    input_type=_ADDTIMEOFFLIGHTINTERVALSREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\0037\0322/api/tco/{instance}/{serviceName}/tof:addIntervals:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTimeOfFlightIntervals',
    full_name='yamcs.protobuf.tco.TimeCorrelationApi.DeleteTimeOfFlightIntervals',
    index=6,
    containing_service=None,
    input_type=_DELETETIMEOFFLIGHTINTERVALSREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003:\0325/api/tco/{instance}/{serviceName}/tof:deleteIntervals:\001*',
  ),
])
_sym_db.RegisterServiceDescriptor(_TIMECORRELATIONAPI)

DESCRIPTOR.services_by_name['TimeCorrelationApi'] = _TIMECORRELATIONAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/config/config.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/config/config.proto',
  package='yamcs.protobuf.config',
  syntax='proto2',
  serialized_options=b'\n\031org.yamcs.protobuf.configB\013ConfigProtoP\001',
  serialized_pb=b'\n\"yamcs/protobuf/config/config.proto\x12\x15yamcs.protobuf.config\x1a\x1cgoogle/protobuf/struct.proto\"\x9a\x02\n\x08SpecInfo\x12\x32\n\x07options\x18\x01 \x03(\x0b\x32!.yamcs.protobuf.config.OptionInfo\x12\x18\n\x10\x61llowUnknownKeys\x18\x02 \x01(\x08\x12=\n\rrequiredOneOf\x18\x03 \x03(\x0b\x32&.yamcs.protobuf.config.OptionGroupInfo\x12?\n\x0frequireTogether\x18\x04 \x03(\x0b\x32&.yamcs.protobuf.config.OptionGroupInfo\x12@\n\x0ewhenConditions\x18\x05 \x03(\x0b\x32(.yamcs.protobuf.config.WhenConditionInfo\"\x1f\n\x0fOptionGroupInfo\x12\x0c\n\x04keys\x18\x01 \x03(\t\"]\n\x11WhenConditionInfo\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value\x12\x14\n\x0crequiredKeys\x18\x03 \x03(\t\"\xb8\x03\n\nOptionInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0e\x32!.yamcs.protobuf.config.OptionType\x12\r\n\x05title\x18\x03 \x01(\t\x12\'\n\x07\x64\x65\x66\x61ult\x18\x04 \x01(\x0b\x32\x16.google.protobuf.Value\x12\x10\n\x08required\x18\x05 \x01(\x08\x12\x0e\n\x06hidden\x18\x06 \x01(\x08\x12\x0e\n\x06secret\x18\x07 \x01(\x08\x12\x14\n\x0cversionAdded\x18\x08 \x01(\t\x12\x1a\n\x12\x64\x65precationMessage\x18\t \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\n \x03(\t\x12\x36\n\x0b\x65lementType\x18\x0b \x01(\x0e\x32!.yamcs.protobuf.config.OptionType\x12-\n\x04spec\x18\x0c \x01(\x0b\x32\x1f.yamcs.protobuf.config.SpecInfo\x12\'\n\x07\x63hoices\x18\r \x03(\x0b\x32\x16.google.protobuf.Value\x12\x19\n\x11\x61pplySpecDefaults\x18\x0e \x01(\x08\x12\x0f\n\x07\x61liases\x18\x0f \x03(\t*n\n\nOptionType\x12\x07\n\x03\x41NY\x10\x01\x12\x0b\n\x07\x42OOLEAN\x10\x02\x12\x0b\n\x07INTEGER\x10\x03\x12\t\n\x05\x46LOAT\x10\x04\x12\x08\n\x04LIST\x10\x05\x12\x13\n\x0fLIST_OR_ELEMENT\x10\x06\x12\x07\n\x03MAP\x10\x07\x12\n\n\x06STRING\x10\x08\x42*\n\x19org.yamcs.protobuf.configB\x0b\x43onfigProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])

_OPTIONTYPE = _descriptor.EnumDescriptor(
  name='OptionType',
  full_name='yamcs.protobuf.config.OptionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ANY', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTEGER', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLOAT', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIST', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIST_OR_ELEMENT', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAP', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=7, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=947,
  serialized_end=1057,
)
_sym_db.RegisterEnumDescriptor(_OPTIONTYPE)

OptionType = enum_type_wrapper.EnumTypeWrapper(_OPTIONTYPE)
ANY = 1
BOOLEAN = 2
INTEGER = 3
FLOAT = 4
LIST = 5
LIST_OR_ELEMENT = 6
MAP = 7
STRING = 8



_SPECINFO = _descriptor.Descriptor(
  name='SpecInfo',
  full_name='yamcs.protobuf.config.SpecInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='options', full_name='yamcs.protobuf.config.SpecInfo.options', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allowUnknownKeys', full_name='yamcs.protobuf.config.SpecInfo.allowUnknownKeys', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requiredOneOf', full_name='yamcs.protobuf.config.SpecInfo.requiredOneOf', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requireTogether', full_name='yamcs.protobuf.config.SpecInfo.requireTogether', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='whenConditions', full_name='yamcs.protobuf.config.SpecInfo.whenConditions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=374,
)


_OPTIONGROUPINFO = _descriptor.Descriptor(
  name='OptionGroupInfo',
  full_name='yamcs.protobuf.config.OptionGroupInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='yamcs.protobuf.config.OptionGroupInfo.keys', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=407,
)


_WHENCONDITIONINFO = _descriptor.Descriptor(
  name='WhenConditionInfo',
  full_name='yamcs.protobuf.config.WhenConditionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.config.WhenConditionInfo.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.config.WhenConditionInfo.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requiredKeys', full_name='yamcs.protobuf.config.WhenConditionInfo.requiredKeys', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=409,
  serialized_end=502,
)


_OPTIONINFO = _descriptor.Descriptor(
  name='OptionInfo',
  full_name='yamcs.protobuf.config.OptionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.config.OptionInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.config.OptionInfo.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='yamcs.protobuf.config.OptionInfo.title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default', full_name='yamcs.protobuf.config.OptionInfo.default', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='required', full_name='yamcs.protobuf.config.OptionInfo.required', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='yamcs.protobuf.config.OptionInfo.hidden', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secret', full_name='yamcs.protobuf.config.OptionInfo.secret', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionAdded', full_name='yamcs.protobuf.config.OptionInfo.versionAdded', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecationMessage', full_name='yamcs.protobuf.config.OptionInfo.deprecationMessage', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.config.OptionInfo.description', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elementType', full_name='yamcs.protobuf.config.OptionInfo.elementType', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='yamcs.protobuf.config.OptionInfo.spec', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='choices', full_name='yamcs.protobuf.config.OptionInfo.choices', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='applySpecDefaults', full_name='yamcs.protobuf.config.OptionInfo.applySpecDefaults', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aliases', full_name='yamcs.protobuf.config.OptionInfo.aliases', index=14,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=945,
)

_SPECINFO.fields_by_name['options'].message_type = _OPTIONINFO
_SPECINFO.fields_by_name['requiredOneOf'].message_type = _OPTIONGROUPINFO
_SPECINFO.fields_by_name['requireTogether'].message_type = _OPTIONGROUPINFO
_SPECINFO.fields_by_name['whenConditions'].message_type = _WHENCONDITIONINFO
_WHENCONDITIONINFO.fields_by_name['value'].message_type = google_dot_protobuf_dot_struct__pb2._VALUE
_OPTIONINFO.fields_by_name['type'].enum_type = _OPTIONTYPE
_OPTIONINFO.fields_by_name['default'].message_type = google_dot_protobuf_dot_struct__pb2._VALUE
_OPTIONINFO.fields_by_name['elementType'].enum_type = _OPTIONTYPE
_OPTIONINFO.fields_by_name['spec'].message_type = _SPECINFO
_OPTIONINFO.fields_by_name['choices'].message_type = google_dot_protobuf_dot_struct__pb2._VALUE
DESCRIPTOR.message_types_by_name['SpecInfo'] = _SPECINFO
DESCRIPTOR.message_types_by_name['OptionGroupInfo'] = _OPTIONGROUPINFO
DESCRIPTOR.message_types_by_name['WhenConditionInfo'] = _WHENCONDITIONINFO
DESCRIPTOR.message_types_by_name['OptionInfo'] = _OPTIONINFO
DESCRIPTOR.enum_types_by_name['OptionType'] = _OPTIONTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpecInfo = _reflection.GeneratedProtocolMessageType('SpecInfo', (_message.Message,), {
  'DESCRIPTOR' : _SPECINFO,
  '__module__' : 'yamcs.protobuf.config.config_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.config.SpecInfo)
  })
_sym_db.RegisterMessage(SpecInfo)

OptionGroupInfo = _reflection.GeneratedProtocolMessageType('OptionGroupInfo', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONGROUPINFO,
  '__module__' : 'yamcs.protobuf.config.config_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.config.OptionGroupInfo)
  })
_sym_db.RegisterMessage(OptionGroupInfo)

WhenConditionInfo = _reflection.GeneratedProtocolMessageType('WhenConditionInfo', (_message.Message,), {
  'DESCRIPTOR' : _WHENCONDITIONINFO,
  '__module__' : 'yamcs.protobuf.config.config_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.config.WhenConditionInfo)
  })
_sym_db.RegisterMessage(WhenConditionInfo)

OptionInfo = _reflection.GeneratedProtocolMessageType('OptionInfo', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONINFO,
  '__module__' : 'yamcs.protobuf.config.config_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.config.OptionInfo)
  })
_sym_db.RegisterMessage(OptionInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
